@@ -231,6 +231,23 @@ list_children_changed_cb (HdyExpanderRow *self)
     gtk_style_context_remove_class (context, "empty");
 }
 
+static void
+hdy_expander_row_destroy (GtkWidget *widget)
+{
+  HdyExpanderRow *self = HDY_EXPANDER_ROW (widget);
+  HdyExpanderRowPrivate *priv = hdy_expander_row_get_instance_private (self);
+
+  if (priv->box) {
+    gtk_widget_destroy (GTK_WIDGET (priv->box));
+    priv->box = NULL;
+    priv->prefixes = NULL;
+    priv->actions = NULL;
+    priv->list = NULL;
+  }
+
+  GTK_WIDGET_CLASS (hdy_expander_row_parent_class)->destroy (widget);
+}
+
 static void
 hdy_expander_row_add (GtkContainer *container,
                       GtkWidget    *child)
@@ -274,6 +291,8 @@ hdy_expander_row_class_init (HdyExpanderRowClass *klass)
   object_class->get_property = hdy_expander_row_get_property;
   object_class->set_property = hdy_expander_row_set_property;
 
+  widget_class->destroy = hdy_expander_row_destroy;
+
   container_class->add = hdy_expander_row_add;
   container_class->remove = hdy_expander_row_remove;
   container_class->forall = hdy_expander_row_forall;
