@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2018 Purism SPC
  *
- * SPDX-License-Identifier: LGPL-2.1+
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #pragma once
@@ -10,6 +10,8 @@
 #error "Only <handy.h> can be included directly."
 #endif
 
+#include "hdy-version.h"
+
 #include <gtk/gtk.h>
 #include "hdy-preferences-row.h"
 
@@ -17,49 +19,64 @@ G_BEGIN_DECLS
 
 #define HDY_TYPE_EXPANDER_ROW (hdy_expander_row_get_type())
 
+HDY_AVAILABLE_IN_ALL
 G_DECLARE_DERIVABLE_TYPE (HdyExpanderRow, hdy_expander_row, HDY, EXPANDER_ROW, HdyPreferencesRow)
 
 /**
  * HdyExpanderRowClass
- * @parent_class: The parent class
+ * @parent_class: the parent class
  */
 struct _HdyExpanderRowClass
 {
   HdyPreferencesRowClass parent_class;
+
+  /*< private >*/
+  gpointer padding[4];
 };
 
+HDY_AVAILABLE_IN_ALL
 GtkWidget   *hdy_expander_row_new (void);
 
-const gchar *hdy_expander_row_get_title (HdyExpanderRow *self);
-void         hdy_expander_row_set_title (HdyExpanderRow *self,
-                                         const gchar    *title);
-
+HDY_AVAILABLE_IN_ALL
 const gchar *hdy_expander_row_get_subtitle (HdyExpanderRow *self);
+HDY_AVAILABLE_IN_ALL
 void         hdy_expander_row_set_subtitle (HdyExpanderRow *self,
                                             const gchar    *subtitle);
 
+HDY_AVAILABLE_IN_ALL
 gboolean hdy_expander_row_get_use_underline (HdyExpanderRow *self);
+HDY_AVAILABLE_IN_ALL
 void     hdy_expander_row_set_use_underline (HdyExpanderRow *self,
                                              gboolean        use_underline);
 
+HDY_AVAILABLE_IN_ALL
 const gchar *hdy_expander_row_get_icon_name (HdyExpanderRow *self);
+HDY_AVAILABLE_IN_ALL
 void         hdy_expander_row_set_icon_name (HdyExpanderRow *self,
                                              const gchar    *icon_name);
 
+HDY_AVAILABLE_IN_ALL
 gboolean hdy_expander_row_get_expanded (HdyExpanderRow *self);
+HDY_AVAILABLE_IN_ALL
 void     hdy_expander_row_set_expanded (HdyExpanderRow *self,
                                         gboolean        expanded);
 
+HDY_AVAILABLE_IN_ALL
 gboolean hdy_expander_row_get_enable_expansion (HdyExpanderRow *self);
+HDY_AVAILABLE_IN_ALL
 void     hdy_expander_row_set_enable_expansion (HdyExpanderRow *self,
                                                 gboolean        enable_expansion);
 
+HDY_AVAILABLE_IN_ALL
 gboolean hdy_expander_row_get_show_enable_switch (HdyExpanderRow *self);
+HDY_AVAILABLE_IN_ALL
 void     hdy_expander_row_set_show_enable_switch (HdyExpanderRow *self,
                                                   gboolean        show_enable_switch);
 
+HDY_AVAILABLE_IN_ALL
 void     hdy_expander_row_add_action (HdyExpanderRow *self,
                                       GtkWidget      *widget);
+HDY_AVAILABLE_IN_ALL
 void     hdy_expander_row_add_prefix (HdyExpanderRow *self,
                                       GtkWidget      *widget);
 
